@@ -84,15 +84,21 @@ my $build_exports = sub {
         },
         action_ok => sub {
             my $action = shift;
-            return Test::More->builder->ok($request->($action)->is_success, @_);
+            my $meth = $request->($action)->request->method;
+            my @args = @_ ? @_ : ("$meth $action returns successfully");
+            return Test::More->builder->ok($request->($action)->is_success,@args);
         },
         action_redirect => sub {
             my $action = shift;
-            return Test::More->builder->ok($request->($action)->is_redirect,@_);
+            my $meth = $request->($action)->request->method;
+            my @args = @_ ? @_ : ("$meth $action returns a redirect");
+            return Test::More->builder->ok($request->($action)->is_redirect,@args);
         },
         action_notfound => sub {
             my $action = shift;
-            return Test::More->builder->is_eq($request->($action)->code,404,@_);
+            my $meth = $request->($action)->request->method;
+            my @args = @_ ? @_ : ("$meth $action returns a 404");
+            return Test::More->builder->is_eq($request->($action)->code,404,@args);
         },
         contenttype_is => sub {
             my $action = shift;
@@ -344,25 +350,29 @@ sub _customize_request {
     }
 }
 
-=head2 action_ok
+=head2 action_ok($url [, $test_name ])
 
-Fetches the given URL and checks that the request was successful.
+Fetches the given URL and checks that the request was successful. An optional
+second argument can be given to specify the name of the test.
 
-=head2 action_redirect
+=head2 action_redirect($url [, $test_name ])
 
-Fetches the given URL and checks that the request was a redirect.
+Fetches the given URL and checks that the request was a redirect. An optional
+second argument can be given to specify the name of the test.
 
-=head2 action_notfound
+=head2 action_notfound($url [, $test_name ])
 
-Fetches the given URL and checks that the request was not found.
+Fetches the given URL and checks that the request was not found. An optional
+second argument can be given to specify the name of the test.
 
-=head2 content_like( $url, $regexp [, $test_name] )
+=head2 content_like( $url, $regexp [, $test_name ] )
 
-Fetches the given URL and returns whether the content matches the regexp.
+Fetches the given URL and returns whether the content matches the regexp. An
+optional third argument can be given to specify the name of the test.
 
-=head2 contenttype_is
+=head2 contenttype_is($url, $type [, $test_name ])
 
-Check for given MIME type.
+Verify the given URL has a content type of $type and optionally specify a test name.
 
 =head1 SEE ALSO
 
