@@ -7,7 +7,8 @@ package TestApp::Controller::Fork;
 use strict;
 use warnings;
 use base 'Catalyst::Controller';
-use YAML;
+
+eval 'use YAML';
 
 sub system : Local {
     my ($self, $c, $ls) = @_;
